Welcome to MTH5's documentation!
======================================
.. image:: source/images/mth5_logo.png
    :align: center

|

.. include:: README.rst

|

.. toctree::
    :maxdepth: 1
    :caption: Contents:

    source/installation
    contributing
    authors
    history
    source/gotchas
    source/conventions
    source/usage
    source/usage_v2
    source/structure
    source/ts
    examples/notebooks/filters_example.ipynb
    examples/notebooks/remove_instrument_response_example.ipynb
    source/file_readers
    examples/notebooks/transfer_function_example.ipynb
    examples/notebooks/mth5_in_parallel.ipynb
    source/examples
    
.. toctree::
    :maxdepth: 1
    :caption: Metadata Standards
    
    source/mt_metadata_guide
    

.. toctree::
    :maxdepth: 4
    :caption: Packages

    source/modules

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
